# ServeIt
[![Build Status](https://travis-ci.org/rtlee9/serveit.svg?branch=master)](https://travis-ci.org/rtlee9/serveit)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/2af32a3840d5441e815f3956659b091f)](https://www.codacy.com/app/ryantlee9/serveit)
[![Codacy Badge](https://api.codacy.com/project/badge/Coverage/2af32a3840d5441e815f3956659b091f)](https://www.codacy.com/app/ryantlee9/serveit)
[![PyPI version](https://badge.fury.io/py/ServeIt.svg)](https://badge.fury.io/py/ServeIt)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE)


ServeIt lets you deploy your models to a RESTful API for prediction serving in one line of code. Current features include:

1. Model prediction serving
1. Supplementary information endpoint creation
1. Input validation and exception handling
1. Configurable request and response logging (work in progress)